package org.jboss.cache.config.parsing.element;

import org.jboss.cache.config.BuddyReplicationConfig;
import org.jboss.cache.config.parsing.XmlParserBase;
import org.jboss.cache.config.parsing.XmlConfigHelper;
import org.jboss.cache.buddyreplication.NextMemberBuddyLocator;
import org.w3c.dom.Element;

import java.util.Properties;

/**
 * Utility class for parsing 'buddy' element in the .xml configuration file.
 * <pre>
 * Note: class does not rely on element position in the configuration file.
 *       It does not rely on element's name either.
 * </pre>
 *
 * @author Mircea.Markus@jboss.com
 * @since 3.0
 */
public class BuddyElementParser extends XmlParserBase
{
   public BuddyReplicationConfig parseBuddyElement(Element element)
   {
      BuddyReplicationConfig brc = new BuddyReplicationConfig();
      String enabled = getAttributeValue(element, "enabled");
      if (existsAttribute(enabled)) brc.setEnabled(getBoolean(enabled));
      String buddyPoolName = getAttributeValue(element, "poolName");
      if (existsAttribute(buddyPoolName)) brc.setBuddyPoolName(buddyPoolName);
      String buddyCommunicationTimeout = getAttributeValue(element, "communicationTimeout");
      if (existsAttribute(buddyCommunicationTimeout))
         brc.setBuddyCommunicationTimeout(getInt(buddyCommunicationTimeout));

      parseDataGravitationElement(getSingleElement("dataGravitation", element), brc);
      BuddyReplicationConfig.BuddyLocatorConfig blc = parseBuddyLocatorConfig(getSingleElement("locator", element));
      brc.setBuddyLocatorConfig(blc);
      return brc;
   }

   private BuddyReplicationConfig.BuddyLocatorConfig parseBuddyLocatorConfig(Element element)
   {
      if (element == null) return defaultBuddyLocatorConfig();
      BuddyReplicationConfig.BuddyLocatorConfig result = new BuddyReplicationConfig.BuddyLocatorConfig();
      String buddyLocatorClass = getAttributeValue(element, "class");
      if (existsAttribute(buddyLocatorClass)) result.setBuddyLocatorClass(buddyLocatorClass);
      Properties existing = new Properties();
      Properties configured = XmlConfigHelper.readPropertiesContents(element, "properties");
      existing.putAll(configured);
      result.setBuddyLocatorClass(buddyLocatorClass);
      result.setBuddyLocatorProperties(existing);
      return result;
   }

   private BuddyReplicationConfig.BuddyLocatorConfig defaultBuddyLocatorConfig()
   {
      BuddyReplicationConfig.BuddyLocatorConfig result = new BuddyReplicationConfig.BuddyLocatorConfig();
      result.setBuddyLocatorClass(NextMemberBuddyLocator.class.getName());
      Properties props = new Properties();
      result.setBuddyLocatorProperties(props);
      return result;
   }

   private void parseDataGravitationElement(Element element, BuddyReplicationConfig brc)
   {
      if (element == null) return;
      String auto = getAttributeValue(element, "auto");
      if (existsAttribute(auto)) brc.setAutoDataGravitation(getBoolean(auto));
      String removeOnFind = getAttributeValue(element, "removeOnFind");
      if (existsAttribute(removeOnFind)) brc.setDataGravitationRemoveOnFind(getBoolean(removeOnFind));
      String searchBackupTrees = getAttributeValue(element, "searchBackupTrees");
      if (existsAttribute(searchBackupTrees)) brc.setDataGravitationSearchBackupTrees(getBoolean(searchBackupTrees));
   }
}
