/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.Fqn;

/**
 * Value object used in evicted event node queue.
 *
 * @author Ben Wang 2-2004
 * @author Daniel Huang (dhuang@jboss.org)
 * @see org.jboss.cache.Region
 */
public class EvictedEventNode
{
   private Fqn fqn;
   private NodeEventType type;
   private int elementDifference;

   private long inUseTimeout;
   private long creationTimestamp;

   public EvictedEventNode(Fqn fqn, NodeEventType type, int elementDifference)
   {
      this(fqn, type);
      setElementDifference(elementDifference);
   }

   public EvictedEventNode(Fqn fqn, NodeEventType event)
   {
      setFqn(fqn);
      setEventType(event);
      creationTimestamp = System.currentTimeMillis();
   }

   public long getCreationTimestamp()
   {
      return creationTimestamp;
   }

   public long getInUseTimeout()
   {
      return inUseTimeout;
   }

   public void setInUseTimeout(long inUseTimeout)
   {
      this.inUseTimeout = inUseTimeout;
   }

   public int getElementDifference()
   {
      return elementDifference;
   }

   public void setElementDifference(int elementDifference_)
   {
      this.elementDifference = elementDifference_;
   }

   public Fqn getFqn()
   {
      return fqn;
   }

   public void setFqn(Fqn fqn)
   {
      this.fqn = fqn;
   }

   public void setEventType(NodeEventType event)
   {
      type = event;
   }

   public NodeEventType getEventType()
   {
      return type;
   }

   @Override
   public String toString()
   {
      return "EvictedEventNode[fqn=" + fqn + " event=" + type + " diff=" + elementDifference + "]";
   }

   /**
    * Copies this evicted event node to create a new one with the same values, except with a new Fqn root.
    *
    * @param newRoot new Fqn root to use
    * @return a new EvictedEventNode instance
    * @see org.jboss.cache.Region#copy(org.jboss.cache.Fqn)
    */
   public EvictedEventNode copy(Fqn newRoot)
   {
      return new EvictedEventNode(Fqn.fromRelativeFqn(newRoot, fqn), type, elementDifference);
   }
}
