package org.jboss.cache.factories;

import org.jboss.cache.NodeFactory;
import org.jboss.cache.PessimisticNodeFactory;
import org.jboss.cache.config.ConfigurationException;
import org.jboss.cache.factories.annotations.DefaultFactoryFor;
import org.jboss.cache.mvcc.MVCCNodeFactory;
import org.jboss.cache.optimistic.OptimisticNodeFactory;

/**
 * Creates node factories.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
@DefaultFactoryFor(classes = NodeFactory.class)
public class NodeMetaFactory extends ComponentFactory
{
   @SuppressWarnings("unchecked")
   protected <T> T construct(Class<T> componentType)
   {
      switch (configuration.getNodeLockingScheme())
      {
         case MVCC:
            return (T) new MVCCNodeFactory();
         case OPTIMISTIC:
            return (T) new OptimisticNodeFactory();
         case PESSIMISTIC:
            return (T) new PessimisticNodeFactory();
         default:
            throw new ConfigurationException("Unknown locking scheme " + configuration.getNodeLockingScheme());
      }
   }
}
