package org.jboss.cache.factories.context;

import org.jboss.cache.config.ConfigurationException;
import org.jboss.cache.factories.ComponentFactory;
import org.jboss.cache.factories.annotations.DefaultFactoryFor;

/**
 * Responsible for creating the appropriate {@link ContextFactory} based on configuration used.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
@DefaultFactoryFor(classes = ContextFactory.class)
public class ContextMetaFactory extends ComponentFactory
{
   @SuppressWarnings("unchecked")
   protected <T> T construct(Class<T> componentType)
   {
      if (log.isTraceEnabled()) log.trace("Cache configuration is " + configuration.getNodeLockingScheme());
      switch (configuration.getNodeLockingScheme())
      {
         case MVCC:
            if (log.isTraceEnabled()) log.trace("Creating an MVCC context factory");
            return (T) new MVCCContextFactory();
         case OPTIMISTIC:
            if (log.isTraceEnabled()) log.trace("Creating an optimistic context factory");
            return (T) new OptimisticContextFactory();
         case PESSIMISTIC:
            if (log.isTraceEnabled()) log.trace("Creating a pessimistic context factory");
            return (T) new PessimisticContextFactory();
      }
      throw new ConfigurationException("Unknown configuration node locking scheme");
   }
}
