package org.jboss.cache.factories.context;

import org.jboss.cache.DataContainer;
import org.jboss.cache.factories.annotations.Inject;
import org.jboss.cache.invocation.InvocationContext;
import org.jboss.cache.invocation.LegacyInvocationContext;
import org.jboss.cache.transaction.PessimisticTransactionContext;
import org.jboss.cache.transaction.TransactionContext;

import javax.transaction.RollbackException;
import javax.transaction.SystemException;
import javax.transaction.Transaction;

/**
 * Constructs contexts for pessimistic locking
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
public class PessimisticContextFactory implements ContextFactory
{
   DataContainer container;

   @Inject
   public void inject(DataContainer container)
   {
      this.container = container;
   }

   public InvocationContext createInvocationContext()
   {
      return new LegacyInvocationContext(container);
   }

   public TransactionContext createTransactionContext(Transaction tx) throws SystemException, RollbackException
   {
      return new PessimisticTransactionContext(tx);
   }
}
