package org.jboss.cache.lock;

import org.jboss.cache.config.Configuration;
import org.jboss.cache.factories.annotations.Inject;
import org.jboss.cache.factories.annotations.Start;
import org.jboss.cache.invocation.InvocationContext;

/**
 * Common lock manager functionality
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
public abstract class AbstractLockManager implements LockManager
{
   protected Configuration configuration;
   protected long lockAcquisitionTimeout;

   @Inject
   public void injectConfiguration(Configuration configuration)
   {
      this.configuration = configuration;
   }

   @Start
   public void setLockAcquisitionTimeout()
   {
      this.lockAcquisitionTimeout = configuration.getLockAcquisitionTimeout();
   }

   public Object getLockOwner(InvocationContext ctx)
   {
      return ctx.getGlobalTransaction() != null ? ctx.getGlobalTransaction() : Thread.currentThread();
   }
}
