package org.jboss.cache.lock;

import org.jboss.cache.NodeSPI;
import org.jboss.cache.invocation.InvocationContext;

import java.util.Collection;

/**
 * An abstract lock manager that deals with Fqns rather than nodes.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
public abstract class FqnLockManager extends AbstractLockManager
{
   public boolean lock(NodeSPI node, LockType lockType, Object owner) throws InterruptedException
   {
      return lock(node.getFqn(), lockType, owner);
   }

   public boolean lock(NodeSPI node, LockType lockType, Object owner, long timeout) throws InterruptedException
   {
      return lock(node.getFqn(), lockType, owner, timeout);
   }

   public boolean lockAndRecord(NodeSPI node, LockType lockType, InvocationContext ctx) throws InterruptedException
   {
      return lockAndRecord(node.getFqn(), lockType, ctx);
   }

   public void unlock(NodeSPI node, Object owner)
   {
      unlock(node.getFqn(), owner);
   }

   public boolean ownsLock(NodeSPI node, Object owner)
   {
      return ownsLock(node.getFqn(), owner);
   }

   public Object getWriteOwner(NodeSPI node)
   {
      return getWriteOwner(node.getFqn());
   }

   public Collection<Object> getReadOwners(NodeSPI node)
   {
      return getReadOwners(node.getFqn());
   }

   public boolean isLocked(NodeSPI node)
   {
      return isLocked(node.getFqn());
   }
}
