package org.jboss.cache.mvcc;

import org.jboss.cache.DataContainer;
import org.jboss.cache.InternalNode;

/**
 * A marker node to represent a null node for repeatable read, so that a read that returns a null can continue to return
 * null.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @since 3.0
 */
public class NullMarkerNode extends RepeatableReadNode
{
   public NullMarkerNode(InternalNode node)
   {
      super(node);
   }

   /**
    * @return always returns true
    */
   @Override
   public boolean isNullNode()
   {
      return true;
   }

   /**
    * @return always returns true so that any get commands, upon getting this node, will ignore the node as though it were removed.
    */
   @Override
   public boolean isDeleted()
   {
      return true;
   }

   /**
    * @return always returns true so that any get commands, upon getting this node, will ignore the node as though it were invalid.
    */
   @Override
   public boolean isValid()
   {
      return false;
   }

   /**
    * A no-op.
    */
   @Override
   public void markForUpdate(DataContainer d, boolean b)
   {
      // no op
   }
}
