package org.jboss.cache.util.concurrent;

import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Future;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

/**
 * An executor that works within the current thread.
 *
 * @author Manik Surtani (<a href="mailto:manik@jboss.org">manik@jboss.org</a>)
 * @see <a href="http://jcip.net/">Java Concurrency In Practice</a>
 * @since 3.0
 */
public class WithinThreadExecutor implements ExecutorService
{
   boolean shutDown = false;

   public void execute(Runnable command)
   {
      command.run();
   }

   public void shutdown()
   {
      shutDown = true;
   }

   public List<Runnable> shutdownNow()
   {
      shutDown = true;
      return Collections.emptyList();
   }

   public boolean isShutdown()
   {
      return shutDown;
   }

   public boolean isTerminated()
   {
      return shutDown;
   }

   public boolean awaitTermination(long timeout, TimeUnit unit) throws InterruptedException
   {
      return shutDown;
   }

   public <T> Future<T> submit(Callable<T> task)
   {
      throw new UnsupportedOperationException();
   }

   public <T> Future<T> submit(Runnable task, T result)
   {
      throw new UnsupportedOperationException();
   }

   public Future<?> submit(Runnable task)
   {
      throw new UnsupportedOperationException();
   }

   @SuppressWarnings("unchecked")
   // unchecked on purpose due to http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6267833
   public List invokeAll(Collection tasks) throws InterruptedException
   {
      throw new UnsupportedOperationException();
   }

   @SuppressWarnings("unchecked")
   // unchecked on purpose due to http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6267833
   public List invokeAll(Collection tasks, long timeout, TimeUnit unit) throws InterruptedException
   {
      throw new UnsupportedOperationException();
   }

   @SuppressWarnings("unchecked")
   // unchecked on purpose due to http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6267833
   public Object invokeAny(Collection tasks) throws InterruptedException, ExecutionException
   {
      throw new UnsupportedOperationException();
   }

   @SuppressWarnings("unchecked")
   // unchecked on purpose due to http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6267833
   public Object invokeAny(Collection tasks, long timeout, TimeUnit unit) throws InterruptedException, ExecutionException, TimeoutException
   {
      throw new UnsupportedOperationException();
   }
}
