/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.cache.eviction;

import org.jboss.cache.config.parsing.XmlConfigHelper;
import org.jboss.cache.config.parsing.element.EvictionElementParser;
import static org.testng.AssertJUnit.fail;
import org.testng.annotations.Test;
import org.w3c.dom.Element;

/**
 * Unit tests for NullEvictionPolicyConfig.
 *
 * @author Daniel Huang (dhuang@jboss.org)
 * @version $Revision: 4444 $
 */
@Test(groups = {"functional"})
public class NullEvictionConfigTest
{
   /**
    * Creates a bunch of region elements with LRU configs and confirms
    * that NullEvictionPolicyConfig doesn't barf.
    *
    * @throws Exception
    */
   public void testXMLParsing() throws Exception
   {
      String xml =
            "<region name=\"/org/jboss/data\">\n" +
                  "</region>";

      testConfigBlock(xml);

      xml = "<region name=\"/maxAgeTest/\"/>\n";

      testConfigBlock(xml);
   }

   private void testConfigBlock(String xml) throws Exception
   {
      Element element = XmlConfigHelper.stringToElement(xml);
      NullEvictionPolicyConfig config = new NullEvictionPolicyConfig();
      try
      {
         EvictionElementParser.parseEvictionPolicyConfig(element, config);
      }
      catch (Exception e)
      {
         fail(e.getMessage());
      }
   }
}
