package org.jboss.cache.lock;

import org.jboss.cache.Fqn;
import org.jboss.cache.NodeSPI;
import org.jboss.cache.UnversionedNode;
import org.jboss.cache.factories.context.ContextFactory;
import org.jboss.cache.invocation.InvocationContext;
import org.jboss.cache.invocation.InvocationContextContainer;
import org.jboss.cache.invocation.NodeInvocationDelegate;
import static org.jboss.cache.lock.LockType.WRITE;
import org.jboss.cache.transaction.DummyTransaction;
import org.jboss.cache.transaction.DummyTransactionManager;
import org.jboss.cache.transaction.GlobalTransaction;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.Test;

import javax.transaction.RollbackException;
import javax.transaction.SystemException;

@Test(groups = "unit")
public abstract class AbstractLockManagerRecordingTest
{
   LockManager lm;
   InvocationContextContainer icc;
   protected boolean fqnBasedLocking = true;
   protected ContextFactory contextFactory;

   @AfterMethod
   public void tearDown()
   {
      lm = null;
   }

   public void testRecordingLocksNoTx() throws InterruptedException
   {
      Fqn fqn = Fqn.fromString("/a/b/c");
      NodeSPI node = createNode(fqn);
      InvocationContext ctx = icc.get();

      // lock and record.
      lm.lockAndRecord(node, WRITE, ctx);
      assert ctx.getLocks().contains(fqnBasedLocking ? fqn : node.getLock());
      assert ctx.getLocks().size() == 1;
      assert lm.isLocked(node) : "Should be locked";
      lm.unlock(ctx);
      assert !lm.isLocked(node) : "Should not be locked";
   }

   public void testRecordingLocksWithTx() throws InterruptedException, SystemException, RollbackException
   {
      Fqn fqn = Fqn.fromString("/a/b/c");
      NodeSPI node = createNode(fqn);
      InvocationContext ctx = icc.get();
      ctx.setGlobalTransaction(new GlobalTransaction());
      ctx.setTransaction(new DummyTransaction(DummyTransactionManager.getInstance()));
      ctx.setTransactionContext(contextFactory.createTransactionContext(ctx.getTransaction()));

      // lock and record.
      lm.lockAndRecord(node, WRITE, ctx);
      assert ctx.getLocks().contains(fqnBasedLocking ? fqn : node.getLock());
      assert ctx.getTransactionContext().getLocks().size() == 1;
      assert lm.isLocked(node) : "Should be locked";
      lm.unlock(ctx);
      assert !lm.isLocked(node) : "Should not be locked";
   }

   protected NodeSPI createNode(Fqn fqn)
   {
      UnversionedNode un = new UnversionedNode(fqn);
      return new NodeInvocationDelegate(un);
   }
}
